<?php
/* --------------------------------------------------------------
   dependent.inc.php 2017-11-06
   Gambio GmbH
   http://www.gambio.de
   Copyright © 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

// Get all shipping status icons from database to move them to images/icons/status
$statusImages = $this->query('SELECT `shipping_status_image` FROM `shipping_status`');
if($statusImages->num_rows !== 0)
{
    $imagesOldPath = DIR_FS_CATALOG . 'admin/html/assets/images/legacy/icons/';
    $imagesNewPath = DIR_FS_CATALOG . 'images/icons/status/';
    
    // Create new folder 'status' if it is not existent in images/icons
    if(!is_dir($imagesNewPath))
    {
        mkdir($imagesNewPath);
        chmod($imagesNewPath, 0777);
    }
    
    // Iterate over found images and move them to new destination
    foreach ($statusImages as $image)
    {
        if($image['shipping_status_image'] !== '' && file_exists($imagesOldPath.$image['shipping_status_image']))
        {
            rename($imagesOldPath.$image['shipping_status_image'], $imagesNewPath.$image['shipping_status_image']);
        }
    }
    
    // Always move the gray.png to new destination because it is not saved in the database
    if(file_exists($imagesOldPath.'gray.png'))
    {
        rename($imagesOldPath.'gray.png', $imagesNewPath.'gray.png');
    }
}

$responsiveFileManagerEmailConfiguration = $this->query('SELECT * FROM `configuration_storage` WHERE `key` = "modules/admin/responsivefilemanager/use_in_email_pages";');

// Insert the responsive file manager email configuration value.
if (!count($responsiveFileManagerEmailConfiguration)) {
	$configureResponsiveFileManagerQuery = '
      INSERT INTO `configuration_storage` (`key`, `value`) VALUES
          ("modules/admin/responsivefilemanager/use_in_email_pages", "1");
    ';
	$t_success &= $this->query($configureResponsiveFileManagerQuery, true);
}

// Add index to products_properties_index table to increase performance for deleting combis in backend 
$t_success &= $this->set_index('products_properties_index', 'INDEX',
                               array('products_id', 'properties_values_id', 'properties_id'), 'products_id_3');


/**
 * Add rewrite-url column to product export scheme
 */
$check = $this->query('SELECT * FROM `export_scheme_fields` WHERE `field_name` = "rewrite_url.en"', true);
if($check->num_rows === 0)
{
	$t_success &= is_numeric($this->query('UPDATE `export_scheme_fields` SET `sort_order` = `sort_order`+1 WHERE `scheme_id` = "5" AND `sort_order` >= 56'));
	
	$query     = 'INSERT INTO `export_scheme_fields`
					SET `scheme_id` = "5",
					    `field_name` = "rewrite_url.en",
					    `field_content` = "{rewrite_url.en}",
					    `field_content_default` = "",
					    `created_by` = "gambio",
					    `sort_order` = "56";';
	$t_success &= $this->query($query, true);
}

$check = $this->query('SELECT * FROM `export_scheme_fields` WHERE `field_name` = "rewrite_url.de"', true);
if($check->num_rows === 0)
{
	$t_success &= is_numeric($this->query('UPDATE `export_scheme_fields` SET `sort_order` = `sort_order`+1 WHERE `scheme_id` = "5" AND `sort_order` >= 67'));
	
	$query     = 'INSERT INTO `export_scheme_fields`
					SET `scheme_id` = "5",
					    `field_name` = "rewrite_url.de",
					    `field_content` = "{rewrite_url.de}",
					    `field_content_default` = "",
					    `created_by` = "gambio",
					    `sort_order` = "67";';
	$t_success &= $this->query($query, true);
}

/**
 * Fix content urls
 */

function sanitizeUrl($rewriteUrl)
{
	$search  = array('ä', 'Ä', 'ö', 'Ö', 'ü', 'Ü', '&auml;', '&Auml;', '&ouml;', '&Ouml;', '&uuml;', '&Uuml;', 'ß', '&szlig;');
	$replace = array('ae', 'Ae', 'oe', 'Oe', 'ue', 'Ue', 'ae', 'Ae', 'oe', 'Oe', 'ue', 'Ue', 'ss', 'ss');
	$string  = str_replace($search, $replace, $rewriteUrl);
	
	$search  = array('А', 'Б', 'В', 'Г', 'Д', 'Е', 'Ё', 'Ж', 'З', 'И', 'Й', 'К', 'Л', 'М', 'Н', 'О', 'П', 'Р', 'С', 'Т', 'У', 'Ф', 'Х', 'Ц', 'Ч', 'Ш', 'Щ', 'Ъ', 'Ы', 'Ь', 'Э', 'Ю', 'Я', 'а', 'б', 'в', 'г', 'д', 'е', 'ё', 'ж', 'з', 'и', 'й', 'к', 'л', 'м', 'н', 'о', 'п', 'р', 'с', 'т', 'у', 'ф', 'х', 'ц', 'ч', 'ш', 'щ', 'ъ', 'ы', 'ь', 'э', 'ю', 'я');
	$replace = array('A', 'B', 'W', 'G', 'D', 'Ie', 'Io', 'Z', 'Z', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'R', 'S', 'T', 'U', 'F', 'Ch', 'C', 'Tch', 'Sh', 'Shtch', '', 'Y', '', 'E', 'Iu', 'Ia', 'a', 'b', 'w', 'g', 'd', 'ie', 'io', 'z', 'z', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'r', 's', 't', 'u', 'f', 'ch', 'c', 'tch', 'sh', 'shtch', '', 'y', '', 'e', 'iu', 'ia');
	$string  = str_replace($search, $replace, $string);
	
	$search  = array('Á', 'À', 'Â', 'Ä', 'Ă', 'Ā', 'Ã', 'Å', 'Ą', 'Æ', 'Ć', 'Ċ', 'Ĉ', 'Č', 'Ç', 'Ď', 'Đ', 'Ð', 'É', 'È', 'Ė', 'Ê', 'Ë', 'Ě', 'Ē', 'Ę', 'Ə', 'Ġ', 'Ĝ', 'Ğ', 'Ģ', 'á', 'à', 'â', 'ä', 'ă', 'ā', 'ã', 'å', 'ą', 'æ', 'ć', 'ċ', 'ĉ', 'č', 'ç', 'ď', 'đ', 'ð', 'é', 'è', 'ė', 'ê', 'ë', 'ě', 'ē', 'ę', 'ə', 'ġ', 'ĝ', 'ğ', 'ģ', 'Ĥ', 'Ħ', 'I', 'Í', 'Ì', 'İ', 'Î', 'Ï', 'Ī', 'Į', 'Ĳ', 'Ĵ', 'Ķ', 'Ļ', 'Ł', 'Ń', 'Ň', 'Ñ', 'Ņ', 'Ó', 'Ò', 'Ô', 'Ö', 'Õ', 'Ő', 'Ø', 'Ơ', 'Œ', 'ĥ', 'ħ', 'ı', 'í', 'ì', 'i', 'î', 'ï', 'ī', 'į', 'ĳ', 'ĵ', 'ķ', 'ļ', 'ł', 'ń', 'ň', 'ñ', 'ņ', 'ó', 'ò', 'ô', 'ö', 'õ', 'ő', 'ø', 'ơ', 'œ', 'Ŕ', 'Ř', 'Ś', 'Ŝ', 'Š', 'Ş', 'Ť', 'Ţ', 'Þ', 'Ú', 'Ù', 'Û', 'Ü', 'Ŭ', 'Ū', 'Ů', 'Ų', 'Ű', 'Ư', 'Ŵ', 'Ý', 'Ŷ', 'Ÿ', 'Ź', 'Ż', 'Ž', 'ŕ', 'ř', 'ś', 'ŝ', 'š', 'ş', 'ß', 'ť', 'ţ', 'þ', 'ú', 'ù', 'û', 'ü', 'ŭ', 'ū', 'ů', 'ų', 'ű', 'ư', 'ŵ', 'ý', 'ŷ', 'ÿ', 'ź', 'ż', 'ž');
	$replace = array('A', 'A', 'A', 'A', 'A', 'A', 'A', 'A', 'A', 'AE', 'C', 'C', 'C', 'C', 'C', 'D', 'D', 'D', 'E', 'E', 'E', 'E', 'E', 'E', 'E', 'E', 'G', 'G', 'G', 'G', 'G', 'a', 'a', 'a', 'a', 'a', 'a', 'a', 'a', 'a', 'ae', 'c', 'c', 'c', 'c', 'c', 'd', 'd', 'd', 'e', 'e', 'e', 'e', 'e', 'e', 'e', 'e', 'g', 'g', 'g', 'g', 'g', 'H', 'H', 'I', 'I', 'I', 'I', 'I', 'I', 'I', 'I', 'IJ', 'J', 'K', 'L', 'L', 'N', 'N', 'N', 'N', 'O', 'O', 'O', 'O', 'O', 'O', 'O', 'O', 'CE', 'h', 'h', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'ij', 'j', 'k', 'l', 'l', 'n', 'n', 'n', 'n', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'R', 'R', 'S', 'S', 'S', 'S', 'T', 'T', 'T', 'U', 'U', 'U', 'U', 'U', 'U', 'U', 'U', 'U', 'U', 'W', 'Y', 'Y', 'Y', 'Z', 'Z', 'Z', 'r', 'r', 's', 's', 's', 's', 'B', 't', 't', 'b', 'u', 'u', 'u', 'u', 'u', 'u', 'u', 'u', 'u', 'u', 'w', 'y', 'y', 'y', 'z', 'z', 'z');
	$string  = str_replace($search, $replace, $string);
	
	$string = strtolower($string);
	
	$string = preg_replace('/[^a-z0-9\/]/', '-', $string);
	$string = preg_replace('/--+/', '-', $string);
	$string = preg_replace('/^-(.+)/', "$1", $string);
	$string = preg_replace('/(.+)-$/', "$1", $string);
	
	return $string;
}

function sanitizeUrlKeywords($keywords, $replace = '-')
{
	$searchArray  = array('ä', 'Ä', 'ö', 'Ö', 'ü', 'Ü', '&auml;', '&Auml;', '&ouml;', '&Ouml;', '&uuml;', '&Uuml;', 'ß', '&szlig;');
	$replaceArray = array('ae', 'Ae', 'oe', 'Oe', 'ue', 'Ue', 'ae', 'Ae', 'oe', 'Oe', 'ue', 'Ue', 'ss', 'ss');
	$keywords     = str_replace($searchArray, $replaceArray, $keywords);
	
	$replaceParam = '/[^a-zA-Z0-9]/';
	$keywords     = preg_replace($replaceParam, $replace, $keywords);
	
	return $keywords;
}

$languageCodes = [];
$languages = $this->query('SELECT `languages_id`, `code` FROM `languages`');
foreach($languages as $language)
{
	$languageCodes[$language['languages_id']] = $language['code'];
}

$urlKeywordsAndRewrites = $this->query('SELECT 
											c.`content_group`, 
											c.`languages_id`, 
											c.`gm_url_keywords`, 
											u.`rewrite_url`,
											u.`target_url`
										FROM `content_manager` c 
										LEFT JOIN `url_rewrites` AS u ON (
											u.`content_type` = "content" AND 
											u.`content_id` = c.`content_group` AND 
											u.`language_id` = c.`languages_id`)');

foreach($urlKeywordsAndRewrites as $entry)
{
	if($entry['gm_url_keywords'] === $entry['rewrite_url'])
	{
		$t_success &= $this->query('DELETE FROM `url_rewrites` 
									WHERE 
										`content_type` = "content" AND 
										`content_id` = ' . $entry['content_group'] . ' AND 
										`language_id` = ' . $entry['languages_id'], true);
	} 
	elseif($entry['rewrite_url'] !== null 
	       && $entry['rewrite_url'] !== sanitizeUrl($entry['rewrite_url']) 
	       && $entry['rewrite_url'] === sanitizeUrlKeywords($entry['rewrite_url'])) 
	{
		$update = 'UPDATE `content_manager` 
					SET `gm_url_keywords` = "' . sanitizeUrlKeywords($entry['rewrite_url']) . '"
					WHERE 
						`content_group` = ' . $entry['content_group'] . ' AND 
						`languages_id` = ' . $entry['languages_id'];
		$t_success &= is_numeric($this->query($update));
		
		$t_success &= $this->query('DELETE FROM `url_rewrites` 
									WHERE 
										`content_type` = "content" AND 
										`content_id` = ' . $entry['content_group'] . ' AND 
										`language_id` = ' . $entry['languages_id'], true);
	}
	else
	{
		$update = 'UPDATE `content_manager` 
					SET `gm_url_keywords` = "' . sanitizeUrlKeywords($entry['gm_url_keywords']) . '"
					WHERE 
						`content_group` = ' . $entry['content_group'] . ' AND 
						`languages_id` = ' . $entry['languages_id'];
		$t_success &= is_numeric($this->query($update));
		
		if($entry['rewrite_url'] !== null)
		{
			$targetUrl = $entry['target_url'];
			if(strpos($targetUrl, '&language=') === false)
			{
				$targetUrl .= '&language=' . $languageCodes[$entry['languages_id']];
			}
			
			$update = 'UPDATE `url_rewrites` 
						SET 
							`rewrite_url` = "' . sanitizeUrl($entry['rewrite_url']) . '", 
							`target_url` = "' . $targetUrl . '"
						WHERE 
							`content_type` = "content" AND 
							`content_id` = ' . $entry['content_group'] . ' AND 
							`language_id` = ' . $entry['languages_id'];
			$t_success &= is_numeric($this->query($update));
		}
	}
}